==> swagger_dart_code_generator-2.7.6.tar.gz: lib/src/extensions/string_extension.dart <==
import 'package:recase/recase.dart';
import 'package:swagger_dart_code_generator/src/code_generators/constants.dart';
import 'package:swagger_dart_code_generator/src/code_generators/swagger_models_generator.dart';

extension CapitalizeExtension on String {
  String get capitalize {
    return isEmpty ? this : (this[0].toUpperCase() + substring(1));
  }

  String get lower {
    return isEmpty ? this : (this[0].toLowerCase() + substring(1));
  }

  bool get isUpper {
    return this == toUpperCase() && this != toLowerCase();
  }
}

extension TypeExtension on String {
  String makeNullable() {
    if (endsWith('?')) {
      return this;
    }

    return '$this?';
  }

  String removeNullable() => replaceAll('?', '');

  String getRef() => split('/').last.pascalCase;

  String getUnformattedRef() => split('/').last;

  String withPostfix(String postfix) => '${this}$postfix';

  String asList() => 'List<$this>';

  String removeListOrStream() =>
      replaceAll('List<', '').replaceAll('Stream<', '').replaceAll('>', '');

  String asEnum() => 'enums.$this';

  String asFuture() => 'Future<$this>';

  String asDoubleGeneric() => '$this<T, V>';

  String asGenerics() => '$this<T>';

  String asFutureResponse() => 'Future<chopper.Response<$this>>';

  String asParameterName() {
    return SwaggerModelsGenerator.getValidatedParameterName(this);
  }

  String asParameterType() {
    if (isEmpty) {
      return kDynamic;
    }

    final result =
        split('-').map((String str) => str == str.capitalize).toList().join();

    return result;
  }
}

==> swagger_dart_code_generator-2.11.6.tar.gz: lib/src/extensions/string_extension.dart <==
import 'package:recase/recase.dart';
import 'package:swagger_dart_code_generator/src/code_generators/constants.dart';
import 'package:swagger_dart_code_generator/src/code_generators/swagger_models_generator.dart';

extension CapitalizeExtension on String {
  String get capitalize {
    return isEmpty ? this : (this[0].toUpperCase() + substring(1));
  }

  String get lower {
    return isEmpty ? this : (this[0].toLowerCase() + substring(1));
  }

  bool get isUpper {
    return this == toUpperCase() && this != toLowerCase();
  }
}

extension TypeExtension on String {
  String makeNullable() {
    if (this == kDynamic) {
      return this;
    }

    if (endsWith('?')) {
      return this;
    }

    return '$this?';
  }

  String getRef() => split('/').last.pascalCase;

  String getUnformattedRef() => split('/').last;

  String withPostfix(String postfix) => this + postfix;

  String asList() => 'List<$this>';

  String removeListOrStream() =>
      replaceAll('List<', '').replaceAll('Stream<', '').replaceAll('>', '');

  String asEnum() => 'enums.$this';

  String asFutureResponse() => 'Future<chopper.Response<$this>>';

  String asParameterName() {
    final result = SwaggerModelsGenerator.getValidatedParameterName(this);

    if (result.isEmpty) {
      return '\$';
    }

    return result;
  }

  String asParameterType() {
    if (isEmpty) {
      return kDynamic;
    }

    final result =
        split('-').map((String str) => str == str.capitalize).toList().join();

    return result;
  }
}
